aboutsummaryrefslogtreecommitdiff
path: root/clint.py
diff options
context:
space:
mode:
Diffstat (limited to 'clint.py')
-rwxr-xr-xclint.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/clint.py b/clint.py
index b5321127d7..756a21e5ab 100755
--- a/clint.py
+++ b/clint.py
@@ -627,7 +627,7 @@ class FileInfo:
return os.path.abspath(self._filename).replace('\\', '/')
def RelativePath(self):
"""FullName with /home/julian/c/neovim/src/ chopped off."""
fullname = self.FullName()
if os.path.exists(fullname):
@@ -639,7 +639,7 @@ class FileInfo:
root_dir = os.path.dirname(root_dir)
if os.path.exists(os.path.join(root_dir, ".git")):
- root_dir = os.path.join(root_dir, "src")
+ root_dir = os.path.join(root_dir, "src", "nvim")
prefix = os.path.commonprefix([root_dir, project_dir])
return fullname[len(prefix) + 1:]
@@ -627,7 +627,7 @@ class FileInfo:
return os.path.abspath(self._filename).replace('\\', '/')
def RelativePath(self):
- """FullName with /home/julian/c/neovim/src/ chopped off."""
+ """FullName with <prefix>/src/nvim/ chopped off."""
fullname = self.FullName()
if os.path.exists(fullname):